@@ -1,4 +1,4 @@
 from os.path import abspath, dirname, join
 
-config_path = abspath(join(dirname(__file__)))
+config_path = abspath(dirname(__file__))
 filters_path = join(config_path, 'filters')
