@@ -5,23 +5,35 @@ Module to hold some functions used by different subpackages.
 """
 
 import sys
-import numpy as np
-import pandas as pd
 from collections.abc import Iterable
 from numbers import Number
-from numpy import ndarray
+from os.path import join
 from string import capwords
 from os.path import join
 from gaiaxpy.config.paths import config_path
 
+import numpy as np
+import pandas as pd
+from numpy import ndarray
+
+from gaiaxpy.config.paths import filters_path, config_path
+from gaiaxpy.core.satellite import BANDS
+from gaiaxpy.generator.config import get_additional_filters_path
+
+
+def _get_built_in_systems() -> list:
+    f = open(join(config_path, 'available_systems.txt'), 'r')
+    built_in_systems = f.read().splitlines()
+    return built_in_systems
+
+
+def _is_built_in_system(system):
+    return system in _get_built_in_systems()
+
 
 def cast_output(output):
-    cast_dict = {'source_id': 'int64',
-                 'solution_id': 'int64'}
-    if not isinstance(output, pd.DataFrame):
-        df = output.data
-    else:
-        df = output
+    cast_dict = {'source_id': 'int64', 'solution_id': 'int64'}
+    df = output if isinstance(output, pd.DataFrame) else output.data
     for key, value in cast_dict.items():
         try:
             df[key] = df[key].astype(value)
@@ -30,6 +42,17 @@ def cast_output(output):
     return df
 
 
+def parse_band(band):
+    if isinstance(band, str):
+        band = band.lower()
+    elif isinstance(band, list) and len(band) == 1:
+        band = band[0].lower()
+    if band in BANDS:
+        return band
+    else:
+        raise ValueError(f"String {band} is not a valid band. Band must be either 'bp' or 'rp'.")
+
+
 def str_to_array(str_array):
     if isinstance(str_array, str):
         try:
@@ -43,7 +66,7 @@ def str_to_array(str_array):
 
 
 def _validate_pwl_sampling(sampling):
-    # Receives a numpy array. Validates sampling in pwl.
+    # Receives a NumPy array. Validates sampling in pwl.
     min_sampling_value = -10
     max_sampling_value = 70
     if sampling is None:
@@ -53,14 +76,14 @@ def _validate_pwl_sampling(sampling):
     # Must be a numpy array
     if type(sampling) != ndarray:
         raise TypeError('Sampling must be a NumPy array.')
-    # Array must be sorted in ascendent order
-    sorted_sampling = np.sort(sampling)
-    if not np.array_equal(sampling, sorted_sampling):
-        raise ValueError('Sampling must be in ascendent order.')
+    # Array must be sorted in ascending order
+    if not np.array_equal(sampling, np.sort(sampling)):
+        raise ValueError('Sampling must be in ascending order.')
     min_value = sampling[0]
     max_value = sampling[-1]
     if min_value < min_sampling_value or max_value > max_sampling_value:
-        raise ValueError(f'Wrong value for sampling. Sampling accepts an array of values where the minimum value is {min_sampling_value} and the maximum is {max_sampling_value}.')
+        raise ValueError(f'Wrong value for sampling. Sampling accepts an array of values where the minimum value is '
+                         f'{min_sampling_value} and the maximum is {max_sampling_value}.')
 
 
 def _validate_wl_sampling(sampling):
@@ -71,7 +94,8 @@ def _validate_wl_sampling(sampling):
         if sampling[0] >= sampling[-1]:
             raise ValueError('Sampling should be a non-decreasing array.')
         elif sampling[0] < min_value or sampling[-1] > max_value:
-            raise ValueError(f'Wrong value for sampling. Sampling accepts an array of values where the minimum value is {min_value} and the maximum is {max_value}.')
+            raise ValueError(f'Wrong value for sampling. Sampling accepts an array of values where the minimum value '
+                             f'is {min_value} and the maximum is {max_value}.')
 
 
 def _warning(message):
@@ -81,9 +105,10 @@ def _warning(message):
 def _validate_arguments(default_output_file, given_output_file, save_file):
     if save_file and not isinstance(save_file, bool):
         raise ValueError("Parameter 'save_file' must contain a boolean value.")
-    # If the user gave a number different than the default value, but didn't set save_file to True
-    if default_output_file != given_output_file and save_file == False:
-        _warning('Argument output_file was given, but save_file is set to False. Set save_file to True to store the output of the function.')
+    # If the user input a number different to the default value, but didn't set save_file to True
+    if default_output_file != given_output_file and not save_file:
+        _warning('Argument output_file was given, but save_file is set to False. Set save_file to True to store the '
+                 'output of the function.')
 
 
 def _get_spectra_type(spectra):
@@ -110,18 +135,23 @@ def _get_system_label(name):
     Returns:
         str: A short description of the photometric system.
     """
+
     def snake_to_pascal(word):
         return capwords(word.replace("_", " ")).replace(" ", "")
-    return snake_to_pascal(name)
+
+    return snake_to_pascal(name) if _is_built_in_system(name) else name
+
+
+def _get_system_path(is_built_in):
+    return filters_path if is_built_in else get_additional_filters_path()
 
 
 # AVRO files include the values in the diagonal, whereas others don't
 def array_to_symmetric_matrix(array, array_size):
     """
-    Convert the input 1D array into a 2D matrix. The array is assumed to store
-    only the unique elements of a symmetric matrix (i.e. all elements
-    above the diagonal plus the diagonal) in column major order. A full 2D matrix
-    is returned symmetric with respect to the diagonal.
+    Convert the input 1D array into a 2D matrix. The array is assumed to store only the unique elements of a symmetric
+        matrix (i.e. all elements above the diagonal plus the diagonal) in column major order. A full 2D matrix is
+        returned symmetric with respect to the diagonal.
 
     Args:
         array (ndarray): 1D array.
@@ -133,26 +163,23 @@ def array_to_symmetric_matrix(array, array_size):
     Raises:
         TypeError: If array is not of type np.ndarray.
     """
-    def contains_diagonal(array_size, array):
-        return not len(array) == len(np.tril_indices(array_size - 1)[0])
+
+    def contains_diagonal(_array_size, _array):
+        return not len(_array) == len(np.tril_indices(_array_size - 1)[0])
+
     # Bad cases
-    if (not isinstance(array, np.ndarray) and np.isnan(array)) or \
-            isinstance(array_size, np.ma.core.MaskedConstant) or \
-            array.size == 0:
+    if (not isinstance(array, np.ndarray) and np.isnan(array)) or isinstance(array_size, np.ma.core.MaskedConstant) \
+            or array.size == 0:
         return array
     # Enforce array type, second check verifies that array is 1D.
     if isinstance(array, np.ndarray) and isinstance(array[0], Number) and isinstance(array_size, Number):
         array_size = int(array_size)
-        k = -1  # Diagonal offset (from Numpy documentation)
         matrix = np.zeros((array_size, array_size))
-        # Add values in diagonal
-        np.fill_diagonal(matrix, 1.0)
-        if contains_diagonal(array_size, array):
-            k = 0
+        np.fill_diagonal(matrix, 1.0)  # Add values in diagonal
+        k = 0 if contains_diagonal(array_size, array) else -1  # Diagonal offset (from Numpy documentation)
         matrix[np.tril_indices(array_size, k=k)] = array
         transpose = matrix.transpose()
-        transpose[np.tril_indices(
-            array_size, -1)] = matrix[np.tril_indices(array_size, -1)]
+        transpose[np.tril_indices(array_size, -1)] = matrix[np.tril_indices(array_size, -1)]
         return transpose
     elif isinstance(array, np.ndarray) and isinstance(array[0], np.ndarray):
         # Input array is already a matrix, we assume that it contains the required values.
@@ -168,14 +195,13 @@ def _extract_systems_from_data(data_columns, photometric_system=None):
     columns = list(data_columns.copy())
     if src in columns:
         columns.remove(src)
-    if photometric_system is None:
+    if photometric_system:
+        photometric_system = photometric_system if isinstance(photometric_system, list) else [photometric_system]
+        systems = [system.get_system_label() for system in photometric_system]
+    else:
         # Infer photometric_system from the data
         column_list = [column.split('_')[0] for column in columns]
         systems = list(dict.fromkeys(column_list))
-    else:
-        if not isinstance(photometric_system, list):
-            photometric_system = [photometric_system]
-        systems = [system.get_system_label() for system in photometric_system]
     return systems
 
 def _get_built_in_systems() -> list:
