@@ -1,5 +1,6 @@
-from gaiaxpy.file_parser.parse_internal_continuous import InternalContinuousParser
 from gaiaxpy.file_parser.parse_external import ExternalParser
+from gaiaxpy.file_parser.parse_internal_continuous import InternalContinuousParser
+
 
 def external():
     return ExternalParser()
@@ -12,12 +13,16 @@ def internal_continuous():
 def raise_error():
     raise ValueError('File parser not implemented. This function cannot receive a file as input.')
 
+
 function_parser_dict = {'apply_colour_equation': raise_error,
                         'convert': internal_continuous,
                         '_calibrate': internal_continuous,
                         'calibrate': internal_continuous,
                         'generate': internal_continuous,
-                        'get_inverse_covariance_matrix': internal_continuous}
+                        'get_inverse_covariance_matrix': internal_continuous,
+                        'get_inverse_square_root_covariance_matrix': internal_continuous,
+                        'simulate_continuous': external,
+                        'simulate_sampled': external}
 
 
 class FileReader(object):
