@@ -4,10 +4,11 @@ multi_xp.py
 Module to plot multiple XP spectra.
 """
 
-from .plotter import Plotter
-from gaiaxpy.core.satellite import BANDS
 import matplotlib.pyplot as plt
 
+from gaiaxpy.core.satellite import BANDS
+from .plotter import Plotter
+
 
 class MultiXpPlotter(Plotter):
 
@@ -35,12 +36,15 @@ class MultiXpPlotter(Plotter):
                 handles, labels = plt.gca().get_legend_handles_labels()
                 by_label = dict(zip(labels, handles))
                 fig.subplots_adjust(top=0.95, bottom=0.05, left=0.05, right=0.85, wspace=0.020)
-                fig.legend(by_label.values(), by_label.keys(), bbox_to_anchor=(1, 1), loc='upper right', borderaxespad=0.1)
+                fig.legend(by_label.values(), by_label.keys(), bbox_to_anchor=(1, 1), loc='upper right',
+                           borderaxespad=0.1)
 
     def _plot(self):
         n_spectra = len(self.spectra)
         if self.show_plot and self.legend and n_spectra > self.max_spectra_on_multi:
-            raise ValueError(f'The legend can only be shown for a list of spectra no longer than {self.max_spectra_on_multi} elements. Try setting legend to False or retry with a shorter list.')
+            raise ValueError(f'The legend can only be shown for a list of spectra no longer than '
+                             f'{self.max_spectra_on_multi} elements. Try setting legend to False or retry with a '
+                             f'shorter list.')
         self._plot_multi_xp()
         if self.output_path:
             self._save_figure(self.output_path, self.output_file, self.format)
