@@ -4,15 +4,16 @@ plotter.py
 Module to create a plotter object.
 """
 
-import pandas as pd
-import matplotlib.pyplot as plt
-from pathlib import Path
 from os.path import join
+from pathlib import Path
+
+import matplotlib.pyplot as plt
+import pandas as pd
 
 
 class Plotter(object):
 
-    def __init__(self, spectra, sampling, multi, show_plot, output_path, output_file, format, legend):
+    def __init__(self, spectra, sampling, multi, show_plot, output_path, output_file, _format, legend):
         self.spectra = spectra
         self.spectra_class = _set_class(spectra)
         self.sampling = sampling
@@ -21,7 +22,7 @@ class Plotter(object):
         self.output_path = output_path
         # Here we assume that the list only contains spectra of the same type
         self.output_file = self._set_output_file(output_file)
-        self.format = format
+        self.format = _format
         self.legend = legend
         self.max_spectra_on_multi = 40
         self.max_spectra_on_single = 20
@@ -35,23 +36,17 @@ class Plotter(object):
     def _get_source_id(self, spectrum):
         return spectrum['source_id']
 
-    def _save_figure(self, output_path, output_file, format):
+    def _save_figure(self, output_path, output_file, _format):
         if output_path:
             Path(output_path).mkdir(parents=True, exist_ok=True)
-            plt.savefig(
-                join(output_path, f'{output_file}.{format}'),
-                format=format,
-                transparent=False)
+            plt.savefig(join(output_path, f'{output_file}.{_format}'), format=_format, transparent=False)
 
     def _set_output_file(self, output_file):
-        if not output_file:
-            output_file = self.spectra_class.__name__
-        return output_file
+        return output_file if output_file else self.spectra_class.__name__
 
 
 def _set_class(spectra):
     if isinstance(spectra, pd.DataFrame):
         return spectra.attrs['data_type']
-    # Any other iterable
     else:
-        raise ValueError('Input should be pd.DataFrame.')
+        raise ValueError('Input should be a pandas DataFrame.')
